@@ -1,25 +1,11 @@
 /*
- * Copyright 2020  Arjen Hiemstra <ahiemstra@heimr.nl>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
-#include <QTest>
 #include <QAbstractItemModelTester>
+#include <QTest>
 #include <QTransposeProxyModel>
 
 #include <QDBusInterface>
@@ -49,12 +35,7 @@ private Q_SLOTS:
 
         QVERIFY(model.columnCount() == 0);
 
-        model.setSensors({
-            qs("cpu/all/usage"),
-            qs("memory/physical/used"),
-            qs("network/all/download"),
-            qs("disk/all/used")
-        });
+        model.setSensors({qs("cpu/all/usage"), qs("memory/physical/used"), qs("network/all/download"), qs("disk/all/used")});
 
         QTRY_VERIFY(model.isReady());
 
@@ -74,11 +55,7 @@ private Q_SLOTS:
         QCOMPARE(model.headerData(2, Qt::Horizontal, unit).value<KSysGuard::Unit>(), KSysGuard::UnitByteRate);
         QCOMPARE(model.headerData(3, Qt::Horizontal, unit).value<KSysGuard::Unit>(), KSysGuard::UnitByte);
 
-        model.setSensors({
-            qs("disk/all/used"),
-            qs("network/all/download"),
-            qs("cpu/all/usage")
-        });
+        model.setSensors({qs("disk/all/used"), qs("network/all/download"), qs("cpu/all/usage")});
 
         QVERIFY(!model.isReady());
 
@@ -105,12 +82,7 @@ private Q_SLOTS:
         QTransposeProxyModel transpose;
         transpose.setSourceModel(&model);
 
-        model.setSensors({
-            qs("cpu/all/usage"),
-            qs("memory/physical/used"),
-            qs("network/all/download"),
-            qs("disk/all/used")
-        });
+        model.setSensors({qs("cpu/all/usage"), qs("memory/physical/used"), qs("network/all/download"), qs("disk/all/used")});
 
         QTRY_VERIFY(model.isReady());
 
