@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2020 Marco Martin <mart@kde.org>
+    SPDX-FileCopyrightText: 2020 Marco Martin <mart@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "SensorFaceController.h"
@@ -25,11 +12,11 @@
 
 #include <QtQml>
 
-#include <KDesktopFile>
-#include <KDeclarative/ConfigPropertyMap>
-#include <KPackage/PackageLoader>
-#include <KLocalizedString>
 #include <KConfigLoader>
+#include <KDeclarative/ConfigPropertyMap>
+#include <KDesktopFile>
+#include <KLocalizedString>
+#include <KPackage/PackageLoader>
 #include <KPluginMetaData>
 #include <Solid/Block>
 #include <Solid/Device>
@@ -50,7 +37,7 @@ void FacesModel::reload()
     clear();
 
     auto list = KPackage::PackageLoader::self()->listPackages(QStringLiteral("KSysguard/SensorFace"));
-    // NOTE: This will disable completely the internal in-memory cache 
+    // NOTE: This will disable completely the internal in-memory cache
     KPackage::Package p;
     p.install(QString(), QString());
 
@@ -69,7 +56,7 @@ QString FacesModel::pluginId(int row)
 QHash<int, QByteArray> FacesModel::roleNames() const
 {
     QHash<int, QByteArray> roles = QAbstractItemModel::roleNames();
- 
+
     roles[PluginIdRole] = "pluginId";
     return roles;
 }
@@ -83,9 +70,10 @@ PresetsModel::PresetsModel(QObject *parent)
 void PresetsModel::reload()
 {
     clear();
-    QList<KPluginMetaData> plugins = KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), [](const KPluginMetaData &plugin) {
-        return plugin.value(QStringLiteral("X-Plasma-RootPath")) == QStringLiteral("org.kde.plasma.systemmonitor");
-    });
+    QList<KPluginMetaData> plugins =
+        KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), [](const KPluginMetaData &plugin) {
+            return plugin.value(QStringLiteral("X-Plasma-RootPath")) == QStringLiteral("org.kde.plasma.systemmonitor");
+        });
 
     QSet<QString> usedNames;
 
@@ -110,7 +98,8 @@ void PresetsModel::reload()
         // TODO config
         QVariantMap config;
 
-        KConfigGroup configGroup(KSharedConfig::openConfig(p.filePath("config", QStringLiteral("faceproperties")), KConfig::SimpleConfig), QStringLiteral("Config"));
+        KConfigGroup configGroup(KSharedConfig::openConfig(p.filePath("config", QStringLiteral("faceproperties")), KConfig::SimpleConfig),
+                                 QStringLiteral("Config"));
 
         const QStringList keys = configGroup.keyList();
         for (const QString &key : keys) {
@@ -149,36 +138,36 @@ SensorFaceControllerPrivate::SensorFaceControllerPrivate()
         // id. If it matches, it will be be used to replace the sensor id with
         // the second argument.
         sensorIdReplacements = {
-            { QRegularExpression(QStringLiteral("network/interfaces/(.*)")), QStringLiteral("network/\\1")},
-            { QRegularExpression(QStringLiteral("network/all/receivedDataRate$")), QStringLiteral("network/all/download")},
-            { QRegularExpression(QStringLiteral("network/all/sentDataRate$")), QStringLiteral("network/all/upload")},
-            { QRegularExpression(QStringLiteral("network/all/totalReceivedData$")), QStringLiteral("network/all/totalDownload")},
-            { QRegularExpression(QStringLiteral("network/all/totalSentData$")), QStringLiteral("network/all/totalUpload")},
-            { QRegularExpression(QStringLiteral("(.*)/receiver/data$")), QStringLiteral("\\1/download")},
-            { QRegularExpression(QStringLiteral("(.*)/transmitter/data$")), QStringLiteral("\\1/upload")},
-            { QRegularExpression(QStringLiteral("(.*)/receiver/dataTotal$")), QStringLiteral("\\1/totalDownload")},
-            { QRegularExpression(QStringLiteral("(.*)/transmitter/dataTotal$")), QStringLiteral("\\1/totalUpload")},
-            { QRegularExpression(QStringLiteral("(.*)/Rate/rio")), QStringLiteral("\\1/read")},
-            { QRegularExpression(QStringLiteral("(.*)/Rate/wio$")), QStringLiteral("\\1/write")},
-            { QRegularExpression(QStringLiteral("(.*)/freespace$")), QStringLiteral("\\1/free")},
-            { QRegularExpression(QStringLiteral("(.*)/filllevel$")), QStringLiteral("\\1/usedPercent")},
-            { QRegularExpression(QStringLiteral("(.*)/usedspace$")), QStringLiteral("\\1/used")},
-            { QRegularExpression(QStringLiteral("cpu/system/(.*)$")), QStringLiteral("cpu/all/\\1")},
-            { QRegularExpression(QStringLiteral("cpu/(.*)/sys$")), QStringLiteral("cpu/\\1/system")},
-            { QRegularExpression(QStringLiteral("cpu/(.*)/TotalLoad$")), QStringLiteral("cpu/\\1/usage")},
-            { QRegularExpression(QStringLiteral("cpu/cpu(\\d+)/clock$")), QStringLiteral("cpu/cpu\\1/frequency")},
-            { QRegularExpression(QStringLiteral("mem/(.*)level")), QStringLiteral("mem/\\1Percent")},
-            { QRegularExpression(QStringLiteral("mem/physical/allocated")), QStringLiteral("memory/physical/used")},
-            { QRegularExpression(QStringLiteral("mem/physical/available")), QStringLiteral("memory/physical/free")},
-            { QRegularExpression(QStringLiteral("mem/physical/buf")), QStringLiteral("memory/physical/buffer")},
-            { QRegularExpression(QStringLiteral("mem/physical/cached")), QStringLiteral("memory/physical/cache")},
-            { QRegularExpression(QStringLiteral("^mem/(.*)")), QStringLiteral("memory/\\1")},
-            { QRegularExpression(QStringLiteral("nvidia/(.*)/temperature$")), QStringLiteral("gpu/\\1/temperature")},
-            { QRegularExpression(QStringLiteral("nvidia/(.*)/memoryClock$")), QStringLiteral("gpu/\\1/memoryFrequency")},
-            { QRegularExpression(QStringLiteral("nvidia/(.*)/processorClock$")), QStringLiteral("gpu/\\1/coreFrequency")},
-            { QRegularExpression(QStringLiteral("nvidia/(.*)/(memory|sharedMemory)$")), QStringLiteral("gpu/\\1/usedVram")},
-            { QRegularExpression(QStringLiteral("nvidia/(.*)/(encoderUsage|decoderUsage)$")), QStringLiteral("gpu/\\1/usage")},
-            { QRegularExpression(QStringLiteral("(uptime|system/uptime/uptime)$")), QStringLiteral("os/system/uptime")},
+            {QRegularExpression(QStringLiteral("network/interfaces/(.*)")), QStringLiteral("network/\\1")},
+            {QRegularExpression(QStringLiteral("network/all/receivedDataRate$")), QStringLiteral("network/all/download")},
+            {QRegularExpression(QStringLiteral("network/all/sentDataRate$")), QStringLiteral("network/all/upload")},
+            {QRegularExpression(QStringLiteral("network/all/totalReceivedData$")), QStringLiteral("network/all/totalDownload")},
+            {QRegularExpression(QStringLiteral("network/all/totalSentData$")), QStringLiteral("network/all/totalUpload")},
+            {QRegularExpression(QStringLiteral("(.*)/receiver/data$")), QStringLiteral("\\1/download")},
+            {QRegularExpression(QStringLiteral("(.*)/transmitter/data$")), QStringLiteral("\\1/upload")},
+            {QRegularExpression(QStringLiteral("(.*)/receiver/dataTotal$")), QStringLiteral("\\1/totalDownload")},
+            {QRegularExpression(QStringLiteral("(.*)/transmitter/dataTotal$")), QStringLiteral("\\1/totalUpload")},
+            {QRegularExpression(QStringLiteral("(.*)/Rate/rio")), QStringLiteral("\\1/read")},
+            {QRegularExpression(QStringLiteral("(.*)/Rate/wio$")), QStringLiteral("\\1/write")},
+            {QRegularExpression(QStringLiteral("(.*)/freespace$")), QStringLiteral("\\1/free")},
+            {QRegularExpression(QStringLiteral("(.*)/filllevel$")), QStringLiteral("\\1/usedPercent")},
+            {QRegularExpression(QStringLiteral("(.*)/usedspace$")), QStringLiteral("\\1/used")},
+            {QRegularExpression(QStringLiteral("cpu/system/(.*)$")), QStringLiteral("cpu/all/\\1")},
+            {QRegularExpression(QStringLiteral("cpu/(.*)/sys$")), QStringLiteral("cpu/\\1/system")},
+            {QRegularExpression(QStringLiteral("cpu/(.*)/TotalLoad$")), QStringLiteral("cpu/\\1/usage")},
+            {QRegularExpression(QStringLiteral("cpu/cpu(\\d+)/clock$")), QStringLiteral("cpu/cpu\\1/frequency")},
+            {QRegularExpression(QStringLiteral("mem/(.*)level")), QStringLiteral("mem/\\1Percent")},
+            {QRegularExpression(QStringLiteral("mem/physical/allocated")), QStringLiteral("memory/physical/used")},
+            {QRegularExpression(QStringLiteral("mem/physical/available")), QStringLiteral("memory/physical/free")},
+            {QRegularExpression(QStringLiteral("mem/physical/buf")), QStringLiteral("memory/physical/buffer")},
+            {QRegularExpression(QStringLiteral("mem/physical/cached")), QStringLiteral("memory/physical/cache")},
+            {QRegularExpression(QStringLiteral("^mem/(.*)")), QStringLiteral("memory/\\1")},
+            {QRegularExpression(QStringLiteral("nvidia/(.*)/temperature$")), QStringLiteral("gpu/\\1/temperature")},
+            {QRegularExpression(QStringLiteral("nvidia/(.*)/memoryClock$")), QStringLiteral("gpu/\\1/memoryFrequency")},
+            {QRegularExpression(QStringLiteral("nvidia/(.*)/processorClock$")), QStringLiteral("gpu/\\1/coreFrequency")},
+            {QRegularExpression(QStringLiteral("nvidia/(.*)/(memory|sharedMemory)$")), QStringLiteral("gpu/\\1/usedVram")},
+            {QRegularExpression(QStringLiteral("nvidia/(.*)/(encoderUsage|decoderUsage)$")), QStringLiteral("gpu/\\1/usage")},
+            {QRegularExpression(QStringLiteral("^(uptime|system/uptime/uptime)$")), QStringLiteral("os/system/uptime")},
         };
     }
 }
@@ -245,7 +234,7 @@ QJsonArray SensorFaceControllerPrivate::readSensors(const KConfigGroup &read, co
     return newSensors;
 }
 
-QJsonArray SensorFaceControllerPrivate::readAndUpdateSensors(KConfigGroup& config, const QString& entryName)
+QJsonArray SensorFaceControllerPrivate::readAndUpdateSensors(KConfigGroup &config, const QString &entryName)
 {
     auto original = QJsonDocument::fromJson(config.readEntry(entryName, QString()).toUtf8()).array();
 
@@ -259,7 +248,7 @@ QJsonArray SensorFaceControllerPrivate::readAndUpdateSensors(KConfigGroup& confi
     return newSensors;
 }
 
-void SensorFaceControllerPrivate::resolveSensors(const QJsonArray &partialEntries, std::function<void(const QJsonArray&)> callback)
+void SensorFaceControllerPrivate::resolveSensors(const QJsonArray &partialEntries, std::function<void(const QJsonArray &)> callback)
 {
     if (partialEntries.isEmpty()) {
         callback(partialEntries);
@@ -274,7 +263,7 @@ void SensorFaceControllerPrivate::resolveSensors(const QJsonArray &partialEntrie
             query->sortByName();
             const auto ids = query->sensorIds();
             delete query;
-            std::transform(ids.begin(), ids.end(), std::back_inserter(*sensors), [] (const QString &id) {
+            std::transform(ids.begin(), ids.end(), std::back_inserter(*sensors), [](const QString &id) {
                 return QJsonValue(id);
             });
             if (sensors.use_count() == 1) {
@@ -304,7 +293,7 @@ SensorFace *SensorFaceControllerPrivate::createGui(const QString &qmlPath)
     QObject *guiObject = component->beginCreate(context);
     SensorFace *gui = qobject_cast<SensorFace *>(guiObject);
     if (!gui) {
-        qWarning()<<"ERROR: QML gui" << guiObject << "not a SensorFace instance";
+        qWarning() << "ERROR: QML gui" << guiObject << "not a SensorFace instance";
         guiObject->deleteLater();
         context->deleteLater();
         return nullptr;
@@ -335,8 +324,7 @@ QQuickItem *SensorFaceControllerPrivate::createConfigUi(const QString &file, con
 
     QQmlContext *context = new QQmlContext(engine);
     context->setContextObject(contextObj);
-    QObject *guiObject = component->createWithInitialProperties(
-        initialProperties, context);
+    QObject *guiObject = component->createWithInitialProperties(initialProperties, context);
     QQuickItem *gui = qobject_cast<QQuickItem *>(guiObject);
     Q_ASSERT(gui);
     context->setParent(gui);
@@ -347,16 +335,16 @@ QQuickItem *SensorFaceControllerPrivate::createConfigUi(const QString &file, con
     return gui;
 }
 
-
 SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *engine)
-    : QObject(engine),
-      d(std::make_unique<SensorFaceControllerPrivate>())
+    : QObject(engine)
+    , d(std::make_unique<SensorFaceControllerPrivate>())
 {
     d->q = this;
     d->configGroup = config;
     d->appearanceGroup = KConfigGroup(&config, "Appearance");
     d->sensorsGroup = KConfigGroup(&config, "Sensors");
     d->colorsGroup = KConfigGroup(&config, "SensorColors");
+    d->labelsGroup = KConfigGroup(&config, "SensorLabels");
     d->engine = engine;
     d->syncTimer = new QTimer(this);
     d->syncTimer->setSingleShot(true);
@@ -371,15 +359,15 @@ SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *eng
 
     d->contextObj = new KLocalizedContext(this);
 
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("totalSensors")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("totalSensors")), [this](const QJsonArray &resolvedSensors) {
         d->totalSensors = resolvedSensors;
         Q_EMIT totalSensorsChanged();
     });
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("lowPrioritySensorIds")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("lowPrioritySensorIds")), [this](const QJsonArray &resolvedSensors) {
         d->lowPrioritySensorIds = resolvedSensors;
         Q_EMIT lowPrioritySensorIdsChanged();
     });
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("highPrioritySensorIds")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("highPrioritySensorIds")), [this](const QJsonArray &resolvedSensors) {
         d->highPrioritySensorIds = resolvedSensors;
         Q_EMIT highPrioritySensorIdsChanged();
     });
@@ -397,6 +385,7 @@ SensorFaceController::~SensorFaceController()
             // destruction.
             d->appearanceGroup.markAsClean();
             d->colorsGroup.markAsClean();
+            d->labelsGroup.markAsClean();
             if (d->faceConfigLoader && d->faceConfigLoader->isSaveNeeded()) {
                 d->faceConfigLoader->load();
             }
@@ -406,6 +395,11 @@ SensorFaceController::~SensorFaceController()
     }
 }
 
+KConfigGroup KSysGuard::SensorFaceController::configGroup() const
+{
+    return d->configGroup;
+}
+
 QString SensorFaceController::title() const
 {
     // both Title and title can exist to allow i18n of Title
@@ -425,7 +419,7 @@ void SensorFaceController::setTitle(const QString &title)
 
     d->appearanceGroup.writeEntry("title", title);
     d->syncTimer->start();
-    
+
     emit titleChanged();
 }
 
@@ -446,13 +440,12 @@ void SensorFaceController::setShowTitle(bool show)
     emit showTitleChanged();
 }
 
-
 QJsonArray SensorFaceController::totalSensors() const
 {
     return d->totalSensors;
 }
 
-void  SensorFaceController::setTotalSensors(const QJsonArray &totalSensors)
+void SensorFaceController::setTotalSensors(const QJsonArray &totalSensors)
 {
     if (totalSensors == d->totalSensors) {
         return;
@@ -466,7 +459,7 @@ void  SensorFaceController::setTotalSensors(const QJsonArray &totalSensors)
     d->totalSensors = totalSensors;
     d->syncTimer->start();
     Q_EMIT totalSensorsChanged();
-    d->resolveSensors(totalSensors, [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(totalSensors, [this](const QJsonArray &resolvedSensors) {
         if (resolvedSensors == d->totalSensors) {
             return;
         }
@@ -480,7 +473,6 @@ QJsonArray SensorFaceController::highPrioritySensorIds() const
     return d->highPrioritySensorIds;
 }
 
-
 void SensorFaceController::setHighPrioritySensorIds(const QJsonArray &highPrioritySensorIds)
 {
     if (highPrioritySensorIds == d->highPrioritySensorIds) {
@@ -495,7 +487,7 @@ void SensorFaceController::setHighPrioritySensorIds(const QJsonArray &highPriori
     d->syncTimer->start();
     d->highPrioritySensorIds = highPrioritySensorIds;
     Q_EMIT highPrioritySensorIdsChanged();
-    d->resolveSensors(highPrioritySensorIds, [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(highPrioritySensorIds, [this](const QJsonArray &resolvedSensors) {
         if (resolvedSensors == d->highPrioritySensorIds) {
             return;
         }
@@ -535,6 +527,35 @@ void SensorFaceController::setSensorColors(const QVariantMap &colors)
     emit sensorColorsChanged();
 }
 
+QVariantMap SensorFaceController::sensorLabels() const
+{
+    QVariantMap labels;
+    for (const auto &key : d->labelsGroup.keyList()) {
+        labels[key] = d->labelsGroup.readEntry(key);
+    }
+    return labels;
+}
+
+void SensorFaceController::setSensorLabels(const QVariantMap &labels)
+{
+    if (labels == this->sensorLabels()) {
+        return;
+    }
+
+    d->labelsGroup.deleteGroup();
+    d->labelsGroup = KConfigGroup(&d->configGroup, "SensorLabels");
+
+    for (auto it = labels.cbegin(); it != labels.cend(); ++it) {
+        const auto label = it.value().toString();
+        if (!label.isEmpty()) {
+            d->labelsGroup.writeEntry(it.key(), label);
+        }
+    }
+
+    d->syncTimer->start();
+    emit sensorLabelsChanged();
+}
+
 QJsonArray SensorFaceController::lowPrioritySensorIds() const
 {
     return d->lowPrioritySensorIds;
@@ -554,7 +575,7 @@ void SensorFaceController::setLowPrioritySensorIds(const QJsonArray &lowPriority
     d->lowPrioritySensorIds = lowPrioritySensorIds;
     d->syncTimer->start();
     Q_EMIT lowPrioritySensorIdsChanged();
-    d->resolveSensors(lowPrioritySensorIds, [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(lowPrioritySensorIds, [this](const QJsonArray &resolvedSensors) {
         if (resolvedSensors == d->lowPrioritySensorIds) {
             return;
         }
@@ -639,7 +660,7 @@ void SensorFaceController::setFaceId(const QString &face)
         d->faceConfiguration = nullptr;
     }
     if (d->faceConfigLoader) {
-        d->faceConfigLoader ->deleteLater();
+        d->faceConfigLoader->deleteLater();
         d->faceConfigLoader = nullptr;
     }
 
@@ -652,22 +673,7 @@ void SensorFaceController::setFaceId(const QString &face)
 
     d->faceProperties = KConfigGroup(KSharedConfig::openConfig(d->facePackage.filePath("FaceProperties"), KConfig::SimpleConfig), QStringLiteral("Config"));
 
-    const QString xmlPath = d->facePackage.filePath("mainconfigxml");
-
-    if (!xmlPath.isEmpty()) {
-        QFile file(xmlPath);
-        KConfigGroup cg(&d->configGroup, d->faceId);
-
-        d->faceConfigLoader = new KConfigLoader(cg, &file, this);
-        d->faceConfiguration = new KDeclarative::ConfigPropertyMap(d->faceConfigLoader, this);
-        d->faceConfiguration->setAutosave(d->shouldSync);
-        connect(d->faceConfiguration, &KDeclarative::ConfigPropertyMap::valueChanged, this, [this] (const QString &key) {
-            auto item = d->faceConfigLoader->findItemByName(key);
-            if (item) {
-                item->writeConfig(d->faceConfigLoader->config());
-            }
-        });
-    }
+    reloadFaceConfiguration();
 
     d->appearanceGroup.writeEntry("chartFace", face);
     d->syncTimer->start();
@@ -693,7 +699,7 @@ QQuickItem *SensorFaceController::compactRepresentation()
         return d->compactRepresentation;
     }
 
-    d->compactRepresentation = d->createGui(d->facePackage.filePath("ui", QStringLiteral("CompactRepresentation.qml")));   
+    d->compactRepresentation = d->createGui(d->facePackage.filePath("ui", QStringLiteral("CompactRepresentation.qml")));
     return d->compactRepresentation;
 }
 
@@ -724,8 +730,7 @@ QQuickItem *SensorFaceController::faceConfigUi()
     }
 
     d->faceConfigUi = d->createConfigUi(QStringLiteral(":/FaceDetailsConfig.qml"),
-    {{QStringLiteral("controller"), QVariant::fromValue(this)},
-         {QStringLiteral("source"), filePath}});
+                                        {{QStringLiteral("controller"), QVariant::fromValue(this)}, {QStringLiteral("source"), filePath}});
 
     if (d->faceConfigUi && !d->faceConfigUi->property("item").value<QQuickItem *>()) {
         d->faceConfigUi->deleteLater();
@@ -752,7 +757,7 @@ QQuickItem *SensorFaceController::sensorsConfigUi()
     }
 
     if (d->faceProperties.readEntry("SupportsSensors", true)) {
-        d->sensorsConfigUi = d->createConfigUi(QStringLiteral(":/ConfigSensors.qml"),{{QStringLiteral("controller"), QVariant::fromValue(this)}});
+        d->sensorsConfigUi = d->createConfigUi(QStringLiteral(":/ConfigSensors.qml"), {{QStringLiteral("controller"), QVariant::fromValue(this)}});
     } else {
         d->sensorsConfigUi = new QQuickItem;
     }
@@ -786,23 +791,24 @@ void SensorFaceController::reloadConfig()
         d->faceConfigLoader->load();
     }
 
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("totalSensors")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("totalSensors")), [this](const QJsonArray &resolvedSensors) {
         d->totalSensors = resolvedSensors;
         Q_EMIT totalSensorsChanged();
     });
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("lowPrioritySensorIds")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("lowPrioritySensorIds")), [this](const QJsonArray &resolvedSensors) {
         d->lowPrioritySensorIds = resolvedSensors;
         Q_EMIT lowPrioritySensorIdsChanged();
     });
-    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("highPrioritySensorIds")), [this] (const QJsonArray &resolvedSensors) {
+    d->resolveSensors(d->readAndUpdateSensors(d->sensorsGroup, QStringLiteral("highPrioritySensorIds")), [this](const QJsonArray &resolvedSensors) {
         d->highPrioritySensorIds = resolvedSensors;
         Q_EMIT highPrioritySensorIdsChanged();
     });
 
-    //Force to re-read all the values
+    // Force to re-read all the values
     setFaceId(d->appearanceGroup.readEntry("chartFace", QStringLiteral("org.kde.ksysguard.textonly")));
     Q_EMIT titleChanged();
     Q_EMIT sensorColorsChanged();
+    Q_EMIT sensorLabelsChanged();
     Q_EMIT showTitleChanged();
     Q_EMIT updateRateLimitChanged();
 }
@@ -834,9 +840,8 @@ void SensorFaceController::loadPreset(const QString &preset)
     // Load the title
     setTitle(df.readName());
 
-    //Remove the "custon" value from presets models
-    if (d->availablePresetsModel &&
-        d->availablePresetsModel->data(d->availablePresetsModel->index(0, 0), PresetsModel::PluginIdRole).toString().isEmpty()) {
+    // Remove the "custon" value from presets models
+    if (d->availablePresetsModel && d->availablePresetsModel->data(d->availablePresetsModel->index(0, 0), PresetsModel::PluginIdRole).toString().isEmpty()) {
         d->availablePresetsModel->removeRow(0);
     }
 
@@ -914,7 +919,7 @@ void SensorFaceController::savePreset()
     configGroup.writeEntry(QStringLiteral("totalSensors"), QJsonDocument(totalSensors()).toJson(QJsonDocument::Compact));
     configGroup.writeEntry(QStringLiteral("highPrioritySensorIds"), QJsonDocument(highPrioritySensorIds()).toJson(QJsonDocument::Compact));
     configGroup.writeEntry(QStringLiteral("lowPrioritySensorIds"), QJsonDocument(lowPrioritySensorIds()).toJson(QJsonDocument::Compact));
-    
+
     KConfigGroup colorsGroup(&faceConfig, "SensorColors");
     d->colorsGroup.copyTo(&colorsGroup);
     colorsGroup.sync();
@@ -930,7 +935,7 @@ void SensorFaceController::savePreset()
 
     auto *job = presetPackage.install(dir.path());
 
-    connect(job, &KJob::finished, this, [this, pluginName] () {
+    connect(job, &KJob::finished, this, [this, pluginName]() {
         d->availablePresetsModel->reload();
     });
 }
@@ -947,7 +952,7 @@ void SensorFaceController::uninstallPreset(const QString &pluginId)
     root.cdUp();
     auto *job = presetPackage.uninstall(pluginId, root.path());
 
-    connect(job, &KJob::finished, this, [this] () {
+    connect(job, &KJob::finished, this, [this]() {
         d->availablePresetsModel->reload();
     });
 }
@@ -968,5 +973,34 @@ void SensorFaceController::setShouldSync(bool sync)
     }
 }
 
+void SensorFaceController::reloadFaceConfiguration()
+{
+    const QString xmlPath = d->facePackage.filePath("mainconfigxml");
+
+    if (!xmlPath.isEmpty()) {
+        QFile file(xmlPath);
+        KConfigGroup cg(&d->configGroup, d->faceId);
+
+        if (d->faceConfigLoader) {
+            delete d->faceConfigLoader;
+        }
+
+        if (d->faceConfiguration) {
+            delete d->faceConfiguration;
+        }
+
+        d->faceConfigLoader = new KConfigLoader(cg, &file, this);
+        d->faceConfiguration = new KDeclarative::ConfigPropertyMap(d->faceConfigLoader, this);
+        d->faceConfiguration->setAutosave(d->shouldSync);
+        connect(d->faceConfiguration, &KDeclarative::ConfigPropertyMap::valueChanged, this, [this](const QString &key) {
+            auto item = d->faceConfigLoader->findItemByName(key);
+            if (item) {
+                item->writeConfig(d->faceConfigLoader->config());
+            }
+        });
+
+        Q_EMIT faceConfigurationChanged();
+    }
+}
 
 #include "moc_SensorFaceController.cpp"
