@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2020 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2020 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "process_data_model.h"
@@ -50,10 +37,10 @@ public:
     ProcessAttributeModel *m_attributeModel = nullptr;
     const int m_updateInterval = 2000;
     bool m_flatList = true;
+    KSysGuard::Process *m_removingRowFor = nullptr;
 
     QHash<QString, KSysGuard::ProcessAttribute *> m_availableAttributes;
     QVector<KSysGuard::ProcessAttribute *> m_enabledAttributes;
-
 };
 
 ProcessDataModel::ProcessDataModel(QObject *parent)
@@ -215,7 +202,7 @@ void ProcessDataModel::setEnabledAttributes(const QStringList &enabledAttributes
         connect(attribute, &KSysGuard::ProcessAttribute::dataChanged, this, [this, columnIndex](KSysGuard::Process *process) {
             if (process->pid() != -1) {
                 const QModelIndex index = d->getQModelIndex(process, columnIndex);
-                if (index.isValid()) {
+                if (index.isValid() && process != d->m_removingRowFor) {
                     emit dataChanged(index, index);
                 }
             }
@@ -287,7 +274,7 @@ QModelIndex ProcessDataModel::index(int row, int column, const QModelIndex &pare
             return QModelIndex();
         }
 
-        return createIndex( row, column, d->m_processes->getAllProcesses().at(row));
+        return createIndex(row, column, d->m_processes->getAllProcesses().at(row));
     }
 
     // Tree mode
@@ -329,6 +316,10 @@ void ProcessDataModel::Private::endInsertRow()
 
 void ProcessDataModel::Private::beginRemoveRow(KSysGuard::Process *process)
 {
+    Q_ASSERT(process);
+    Q_ASSERT(!m_removingRowFor);
+
+    m_removingRowFor = process;
     int row = process->parent()->children().indexOf(process);
     Q_ASSERT(row >= 0);
     if (m_flatList) {
@@ -340,19 +331,26 @@ void ProcessDataModel::Private::beginRemoveRow(KSysGuard::Process *process)
 
 void ProcessDataModel::Private::endRemoveRow()
 {
+    m_removingRowFor = nullptr;
     q->endRemoveRows();
 }
 
 void ProcessDataModel::Private::update()
 {
-    m_processes->updateAllProcesses(m_updateInterval, KSysGuard::Processes::StandardInformation | KSysGuard::Processes::IOStatistics);
+    Processes::UpdateFlags flags;
+    for (auto attribute : qAsConst(m_enabledAttributes)) {
+        flags |= attribute->requiredUpdateFlags();
+    }
+
+    m_processes->updateAllProcesses(m_updateInterval, flags);
 }
 
 QModelIndex ProcessDataModel::Private::getQModelIndex(KSysGuard::Process *process, int column) const
 {
     Q_ASSERT(process);
     if (process->pid() == -1)
-        return QModelIndex(); // pid -1 is our fake process meaning the very root (never drawn).  To represent that, we return QModelIndex() which also means the top element
+        return QModelIndex(); // pid -1 is our fake process meaning the very root (never drawn).  To represent that, we return QModelIndex() which also means
+                              // the top element
 
     int row;
 
