@@ -1,49 +1,34 @@
-/*  This file is part of the KDE project
-
-    Copyright (C) 2007 John Tapsell <tapsell@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    SPDX-FileCopyrightText: 2007 John Tapsell <tapsell@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "processes.h"
+#include "processes_atop_p.h"
 #include "processes_base_p.h"
 #include "processes_local_p.h"
 #include "processes_remote_p.h"
-#include "processes_atop_p.h"
 
-#include <QSet>
-#include <QMutableSetIterator>
 #include <QByteArray>
 #include <QElapsedTimer>
+#include <QMutableSetIterator>
+#include <QSet>
 #include <QVariantMap>
 
-//for sysconf
+// for sysconf
 #include <unistd.h>
 
 /* if porting to an OS without signal.h  please #define SIGTERM to something */
 #include <signal.h>
 
-
 namespace KSysGuard
 {
-  class Q_DECL_HIDDEN Processes::Private
-  {
-    public:
-      Private(Processes *q_ptr) {
+class Q_DECL_HIDDEN Processes::Private
+{
+public:
+    Private(Processes *q_ptr)
+    {
         mFakeProcess.setParent(&mFakeProcess);
         mAbstractProcesses = nullptr;
         mHistoricProcesses = nullptr;
@@ -56,50 +41,52 @@ namespace KSysGuard
         mLastError = Error::NoError;
         q = q_ptr;
     }
-      ~Private();
-      void markProcessesAsEnded(long pid);
+    ~Private();
+    void markProcessesAsEnded(long pid);
 
-      QSet<long> mToBeProcessed;
-      QSet<long> mProcessedLastTime;
-      QSet<long> mEndedProcesses; ///< Processes that have finished
+    QSet<long> mToBeProcessed;
+    QSet<long> mEndedProcesses; ///< Processes that have finished
 
-      QHash<long, Process *> mProcesses; ///< This must include mFakeProcess at pid -1
-      QList<Process *> mListProcesses;   ///< A list of the processes.  Does not include mFakeProcesses
-      Process mFakeProcess; ///< A fake process with pid -1 just so that even init points to a parent
+    QHash<long, Process *> mProcesses; ///< This must include mFakeProcess at pid -1
+    QList<Process *> mListProcesses; ///< A list of the processes.  Does not include mFakeProcesses
+    Process mFakeProcess; ///< A fake process with pid -1 just so that even init points to a parent
 
-      AbstractProcesses *mAbstractProcesses; ///< The OS specific code to get the process information
-      ProcessesATop *mHistoricProcesses; ///< A way to get historic information about processes
-      bool mIsLocalHost; ///< Whether this is localhost or not
+    AbstractProcesses *mAbstractProcesses; ///< The OS specific code to get the process information
+    ProcessesATop *mHistoricProcesses; ///< A way to get historic information about processes
+    bool mIsLocalHost; ///< Whether this is localhost or not
 
-      QElapsedTimer mLastUpdated; ///< This is the time we last updated.  Used to calculate cpu usage.
-      long mElapsedTimeMilliSeconds; ///< The number of milliseconds  (1000ths of a second) that passed since the last update
+    QElapsedTimer mLastUpdated; ///< This is the time we last updated.  Used to calculate cpu usage.
+    long mElapsedTimeMilliSeconds; ///< The number of milliseconds  (1000ths of a second) that passed since the last update
 
-      Processes::UpdateFlags mUpdateFlags;
-      bool mHavePreviousIoValues; ///< This is whether we updated the IO value on the last update
-      bool mUsingHistoricalData; ///< Whether to return historical data for updateProcess() etc
-      Processes *q;
+    Processes::UpdateFlags mUpdateFlags;
+    bool mHavePreviousIoValues; ///< This is whether we updated the IO value on the last update
+    bool mUsingHistoricalData; ///< Whether to return historical data for updateProcess() etc
+    Processes *q;
 
-      Error mLastError;
-  };
+    Error mLastError;
+};
 
-Processes::Private::~Private() {
-  Q_FOREACH(Process *process, mProcesses) {
-    if(process != &mFakeProcess)
-      delete process;
-  }
-  mProcesses.clear();
-  mListProcesses.clear();
-  delete mAbstractProcesses;
-  mAbstractProcesses = nullptr;
-  delete mHistoricProcesses;
-  mHistoricProcesses = nullptr;
+Processes::Private::~Private()
+{
+    Q_FOREACH (Process *process, mProcesses) {
+        if (process != &mFakeProcess)
+            delete process;
+    }
+    mProcesses.clear();
+    mListProcesses.clear();
+    delete mAbstractProcesses;
+    mAbstractProcesses = nullptr;
+    delete mHistoricProcesses;
+    mHistoricProcesses = nullptr;
 }
 
-Processes::Processes(const QString &host, QObject *parent) : QObject(parent), d(new Private(this))
+Processes::Processes(const QString &host, QObject *parent)
+    : QObject(parent)
+    , d(new Private(this))
 {
     qRegisterMetaType<KSysGuard::Process::Updates>();
 
-    if(host.isEmpty()) {
+    if (host.isEmpty()) {
         d->mAbstractProcesses = new ProcessesLocal();
     } else {
         ProcessesRemote *remote = new ProcessesRemote(host);
@@ -107,8 +94,8 @@ Processes::Processes(const QString &host, QObject *parent) : QObject(parent), d(
         connect(remote, &ProcessesRemote::runCommand, this, &Processes::runCommand);
     }
     d->mIsLocalHost = host.isEmpty();
-    connect( d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
-    connect( d->mAbstractProcesses, &AbstractProcesses::processUpdated, this, &Processes::processUpdated);
+    connect(d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
+    connect(d->mAbstractProcesses, &AbstractProcesses::processUpdated, this, &Processes::processUpdated);
 }
 Processes::~Processes()
 {
@@ -134,28 +121,28 @@ int Processes::processCount() const
     return d->mListProcesses.count();
 }
 
-bool Processes::updateProcess( Process *ps, long ppid)
+bool Processes::updateProcess(Process *ps, long ppid)
 {
     Process *parent = d->mProcesses.value(ppid, &d->mFakeProcess);
-    Q_ASSERT(parent);  //even init has a non-null parent - the mFakeProcess
+    Q_ASSERT(parent); // even init has a non-null parent - the mFakeProcess
 
-    if(ps->parent() != parent) {
-        emit beginMoveProcess(ps, parent/*new parent*/);
-        //Processes has been reparented
+    if (ps->parent() != parent) {
+        emit beginMoveProcess(ps, parent /*new parent*/);
+        // Processes has been reparented
         Process *p = ps;
         do {
             p = p->parent();
             p->numChildren()--;
-        } while (p->pid()!= -1);
+        } while (p->pid() != -1);
         Q_ASSERT(ps != parent);
         ps->parent()->children().removeAll(ps);
-        ps->setParent(parent);  //the parent has changed
+        ps->setParent(parent); // the parent has changed
         parent->children().append(ps);
         p = ps;
         do {
             p = p->parent();
             p->numChildren()++;
-        } while (p->pid()!= -1);
+        } while (p->pid() != -1);
         emit endMoveProcess();
         Q_ASSERT(ps != parent);
         ps->setParent(parent);
@@ -169,8 +156,9 @@ bool Processes::updateProcess( Process *ps, long ppid)
     return success;
 }
 
-bool Processes::updateProcessInfo(Process *ps) {
-    //Now we can actually get the process info
+bool Processes::updateProcessInfo(Process *ps)
+{
+    // Now we can actually get the process info
     qlonglong oldUserTime = ps->userTime();
     qlonglong oldSysTime = ps->sysTime();
 
@@ -181,7 +169,7 @@ bool Processes::updateProcessInfo(Process *ps) {
     qlonglong oldIoCharactersActuallyRead = 0;
     qlonglong oldIoCharactersActuallyWritten = 0;
 
-    if(d->mUpdateFlags.testFlag(Processes::IOStatistics)) {
+    if (d->mUpdateFlags.testFlag(Processes::IOStatistics)) {
         oldIoCharactersRead = ps->ioCharactersRead();
         oldIoCharactersWritten = ps->ioCharactersWritten();
         oldIoReadSyscalls = ps->ioReadSyscalls();
@@ -192,13 +180,13 @@ bool Processes::updateProcessInfo(Process *ps) {
 
     ps->setChanges(Process::Nothing);
     bool success;
-    if(d->mUsingHistoricalData)
+    if (d->mUsingHistoricalData)
         success = d->mHistoricProcesses->updateProcessInfo(ps->pid(), ps);
     else
         success = d->mAbstractProcesses->updateProcessInfo(ps->pid(), ps);
 
-    //Now we have the process info.  Calculate the cpu usage and total cpu usage for itself and all its parents
-    if(!d->mUsingHistoricalData && d->mElapsedTimeMilliSeconds != 0) {  //Update the user usage and sys usage
+    // Now we have the process info.  Calculate the cpu usage and total cpu usage for itself and all its parents
+    if (!d->mUsingHistoricalData && d->mElapsedTimeMilliSeconds != 0) { // Update the user usage and sys usage
 #ifndef Q_OS_NETBSD
         /* The elapsed time is the d->mElapsedTimeMilliSeconds
          * (which is of the order 2 seconds or so) plus a small
@@ -208,13 +196,13 @@ bool Processes::updateProcessInfo(Process *ps) {
         int elapsedTime = ps->elapsedTimeMilliSeconds();
         ps->setElapsedTimeMilliSeconds(d->mLastUpdated.elapsed());
         elapsedTime = ps->elapsedTimeMilliSeconds() - elapsedTime + d->mElapsedTimeMilliSeconds;
-        if(elapsedTime) {
-            ps->setUserUsage((int)(((ps->userTime() - oldUserTime)*1000.0) / elapsedTime));
-            ps->setSysUsage((int)(((ps->sysTime() - oldSysTime)*1000.0) / elapsedTime));
+        if (elapsedTime) {
+            ps->setUserUsage((int)(((ps->userTime() - oldUserTime) * 1000.0) / elapsedTime));
+            ps->setSysUsage((int)(((ps->sysTime() - oldSysTime) * 1000.0) / elapsedTime));
         }
 #endif
-        if(d->mUpdateFlags.testFlag(Processes::IOStatistics)) {
-            if( d->mHavePreviousIoValues ) {
+        if (d->mUpdateFlags.testFlag(Processes::IOStatistics)) {
+            if (d->mHavePreviousIoValues) {
                 ps->setIoCharactersReadRate((ps->ioCharactersRead() - oldIoCharactersRead) * 1000.0 / elapsedTime);
                 ps->setIoCharactersWrittenRate((ps->ioCharactersWritten() - oldIoCharactersWritten) * 1000.0 / elapsedTime);
                 ps->setIoReadSyscallsRate((ps->ioReadSyscalls() - oldIoReadSyscalls) * 1000.0 / elapsedTime);
@@ -223,7 +211,7 @@ bool Processes::updateProcessInfo(Process *ps) {
                 ps->setIoCharactersActuallyWrittenRate((ps->ioCharactersActuallyWritten() - oldIoCharactersActuallyWritten) * 1000.0 / elapsedTime);
             } else
                 d->mHavePreviousIoValues = true;
-        } else if(d->mHavePreviousIoValues) {
+        } else if (d->mHavePreviousIoValues) {
             d->mHavePreviousIoValues = false;
             ps->setIoCharactersReadRate(0);
             ps->setIoCharactersWrittenRate(0);
@@ -233,12 +221,12 @@ bool Processes::updateProcessInfo(Process *ps) {
             ps->setIoCharactersActuallyWrittenRate(0);
         }
     }
-    if(d->mUsingHistoricalData || d->mElapsedTimeMilliSeconds != 0) {
+    if (d->mUsingHistoricalData || d->mElapsedTimeMilliSeconds != 0) {
         ps->setTotalUserUsage(ps->userUsage());
         ps->setTotalSysUsage(ps->sysUsage());
-        if(ps->userUsage() != 0 || ps->sysUsage() != 0) {
+        if (ps->userUsage() != 0 || ps->sysUsage() != 0) {
             Process *p = ps->parent();
-            while(p->pid() != -1) {
+            while (p->pid() != -1) {
                 p->totalUserUsage() += ps->userUsage();
                 p->totalSysUsage() += ps->sysUsage();
                 emit processChanged(p, true);
@@ -253,13 +241,13 @@ bool Processes::updateProcessInfo(Process *ps) {
 bool Processes::addProcess(long pid, long ppid)
 {
     Process *parent = d->mProcesses.value(ppid);
-    if(!parent) {
-        //Under race conditions, the parent could have already quit
-        //In this case, attach to top leaf
+    if (!parent) {
+        // Under race conditions, the parent could have already quit
+        // In this case, attach to top leaf
         parent = &d->mFakeProcess;
-        Q_ASSERT(parent);  //even init has a non-null parent - the mFakeProcess
+        Q_ASSERT(parent); // even init has a non-null parent - the mFakeProcess
     }
-    //it's a new process - we need to set it up
+    // it's a new process - we need to set it up
     Process *ps = new Process(pid, ppid, parent);
 
     emit beginAddProcess(ps);
@@ -278,32 +266,30 @@ bool Processes::addProcess(long pid, long ppid)
     } while (p->pid() != -1);
     ps->setParentPid(ppid);
 
-    //Now we can actually get the process info
+    // Now we can actually get the process info
     bool success = updateProcessInfo(ps);
     emit endAddProcess();
     return success;
-
 }
-bool Processes::updateOrAddProcess( long pid)
+bool Processes::updateOrAddProcess(long pid)
 {
     long ppid;
-    if(d->mUsingHistoricalData)
+    if (d->mUsingHistoricalData)
         ppid = d->mHistoricProcesses->getParentPid(pid);
     else
         ppid = d->mAbstractProcesses->getParentPid(pid);
 
-    if (ppid == pid) //Shouldn't ever happen
+    if (ppid == pid) // Shouldn't ever happen
         ppid = -1;
 
-    if(d->mToBeProcessed.contains(ppid)) {
-        //Make sure that we update the parent before we update this one.  Just makes things a bit easier.
+    if (d->mToBeProcessed.contains(ppid)) {
+        // Make sure that we update the parent before we update this one.  Just makes things a bit easier.
         d->mToBeProcessed.remove(ppid);
-        d->mProcessedLastTime.remove(ppid); //It may or may not be here - remove it if it is there
         updateOrAddProcess(ppid);
     }
 
     Process *ps = d->mProcesses.value(pid);
-    if(!ps)
+    if (!ps)
         return addProcess(pid, ppid);
     else
         return updateProcess(ps, ppid);
@@ -313,55 +299,58 @@ void Processes::updateAllProcesses(long updateDurationMS, Processes::UpdateFlags
 {
     d->mUpdateFlags = updateFlags;
 
-    if(d->mUsingHistoricalData || d->mLastUpdated.elapsed() >= updateDurationMS || !d->mLastUpdated.isValid())  {
+    if (d->mUsingHistoricalData || d->mLastUpdated.elapsed() >= updateDurationMS || !d->mLastUpdated.isValid()) {
         d->mElapsedTimeMilliSeconds = d->mLastUpdated.restart();
-        if(d->mUsingHistoricalData)
+        if (d->mUsingHistoricalData)
             d->mHistoricProcesses->updateAllProcesses(d->mUpdateFlags);
         else
-            d->mAbstractProcesses->updateAllProcesses(d->mUpdateFlags);  //For a local machine, this will directly call Processes::processesUpdated()
+            d->mAbstractProcesses->updateAllProcesses(d->mUpdateFlags); // For a local machine, this will directly call Processes::processesUpdated()
     }
 }
 
-void Processes::processesUpdated() {
-    //First really delete any processes that ended last time
+void Processes::processesUpdated()
+{
+    // First really delete any processes that ended last time
     long pid;
     {
         QSetIterator<long> i(d->mEndedProcesses);
-        while( i.hasNext() ) {
+        while (i.hasNext()) {
             pid = i.next();
             deleteProcess(pid);
         }
     }
 
-    if(d->mUsingHistoricalData)
+    if (d->mUsingHistoricalData)
         d->mToBeProcessed = d->mHistoricProcesses->getAllPids();
     else
         d->mToBeProcessed = d->mAbstractProcesses->getAllPids();
 
-
-    QSet<long> beingProcessed(d->mToBeProcessed); //keep a copy so that we can replace mProcessedLastTime with this at the end of this function
+    QSet<long> endedProcesses;
+    for (Process *p : d->mListProcesses) {
+        if (!d->mToBeProcessed.contains(p->pid())) {
+            endedProcesses += p->pid();
+        }
+    }
 
     {
         QMutableSetIterator<long> i(d->mToBeProcessed);
-        while( i.hasNext()) {
+        while (i.hasNext()) {
             pid = i.next();
             i.remove();
-            d->mProcessedLastTime.remove(pid); //It may or may not be here - remove it if it is there
-            updateOrAddProcess(pid);  //This adds the process or changes an existing one
-            i.toFront(); //we can remove entries from this set elsewhere, so our iterator might be invalid.  Reset it back to the start of the set
+            updateOrAddProcess(pid); // This adds the process or changes an existing one
+            i.toFront(); // we can remove entries from this set elsewhere, so our iterator might be invalid.  Reset it back to the start of the set
         }
     }
     {
-        QSetIterator<long> i(d->mProcessedLastTime);
-        while( i.hasNext()) {
-            //We saw these pids last time, but not this time.  That means we have to mark them for deletion now
+        QSetIterator<long> i(endedProcesses);
+        while (i.hasNext()) {
+            // We saw these pids last time, but not this time.  That means we have to mark them for deletion now
             pid = i.next();
             d->markProcessesAsEnded(pid);
         }
-        d->mEndedProcesses = d->mProcessedLastTime;
+        d->mEndedProcesses = endedProcesses;
     }
 
-    d->mProcessedLastTime = beingProcessed;  //update the set for next time this function is called
     emit updated();
 }
 
@@ -374,11 +363,11 @@ void Processes::processUpdated(long pid, const Process::Updates &changes)
 
     for (auto entry : changes) {
         switch (entry.first) {
-            case Process::VmPSS:
-                process->setVmPSS(entry.second.toLongLong());
-                break;
-            default:
-                break;
+        case Process::VmPSS:
+            process->setVmPSS(entry.second.toLongLong());
+            break;
+        default:
+            break;
         }
     }
 
@@ -390,7 +379,7 @@ void Processes::Private::markProcessesAsEnded(long pid)
     Q_ASSERT(pid >= 0);
 
     Process *process = mProcesses.value(pid);
-    if(!process)
+    if (!process)
         return;
     process->setStatus(Process::Ended);
     emit q->processChanged(process, false);
@@ -400,10 +389,9 @@ void Processes::deleteProcess(long pid)
     Q_ASSERT(pid >= 0);
 
     Process *process = d->mProcesses.value(pid);
-    if(!process)
+    if (!process)
         return;
-    Q_FOREACH( Process *it, process->children()) {
-        d->mProcessedLastTime.remove(it->pid());
+    Q_FOREACH (Process *it, process->children()) {
         deleteProcess(it->pid());
     }
 
@@ -421,8 +409,8 @@ void Processes::deleteProcess(long pid)
 #ifndef QT_NO_DEBUG
     int i = 0;
 #endif
-    Q_FOREACH( Process *it, d->mListProcesses ) {
-        if(it->index() > process->index())
+    Q_FOREACH (Process *it, d->mListProcesses) {
+        if (it->index() > process->index())
             it->setIndex(it->index() - 1);
 #ifndef QT_NO_DEBUG
         Q_ASSERT(it->index() == i++);
@@ -433,12 +421,13 @@ void Processes::deleteProcess(long pid)
     emit endRemoveProcess();
 }
 
-
-bool Processes::killProcess(long pid) {
+bool Processes::killProcess(long pid)
+{
     return sendSignal(pid, SIGTERM);
 }
 
-bool Processes::sendSignal(long pid, int sig) {
+bool Processes::sendSignal(long pid, int sig)
+{
     auto processes = d->mUsingHistoricalData ? d->mHistoricProcesses : d->mAbstractProcesses;
     auto error = processes->sendSignal(pid, sig);
     if (error != NoError) {
@@ -448,7 +437,8 @@ bool Processes::sendSignal(long pid, int sig) {
     return true;
 }
 
-bool Processes::setNiceness(long pid, int priority) {
+bool Processes::setNiceness(long pid, int priority)
+{
     auto processes = d->mUsingHistoricalData ? d->mHistoricProcesses : d->mAbstractProcesses;
     auto error = processes->setNiceness(pid, priority);
     if (error != NoError) {
@@ -458,7 +448,8 @@ bool Processes::setNiceness(long pid, int priority) {
     return true;
 }
 
-bool Processes::setScheduler(long pid, KSysGuard::Process::Scheduler priorityClass, int priority) {
+bool Processes::setScheduler(long pid, KSysGuard::Process::Scheduler priorityClass, int priority)
+{
     auto processes = d->mUsingHistoricalData ? d->mHistoricProcesses : d->mAbstractProcesses;
     auto error = processes->setScheduler(pid, priorityClass, priority);
     if (error != NoError) {
@@ -468,7 +459,8 @@ bool Processes::setScheduler(long pid, KSysGuard::Process::Scheduler priorityCla
     return true;
 }
 
-bool Processes::setIoNiceness(long pid, KSysGuard::Process::IoPriorityClass priorityClass, int priority) {
+bool Processes::setIoNiceness(long pid, KSysGuard::Process::IoPriorityClass priorityClass, int priority)
+{
     auto processes = d->mUsingHistoricalData ? d->mHistoricProcesses : d->mAbstractProcesses;
     auto error = processes->setIoNiceness(pid, priorityClass, priority);
     if (error != NoError) {
@@ -478,31 +470,35 @@ bool Processes::setIoNiceness(long pid, KSysGuard::Process::IoPriorityClass prio
     return true;
 }
 
-bool Processes::supportsIoNiceness() {
-    if(d->mUsingHistoricalData)
+bool Processes::supportsIoNiceness()
+{
+    if (d->mUsingHistoricalData)
         return d->mHistoricProcesses->supportsIoNiceness();
     return d->mAbstractProcesses->supportsIoNiceness();
 }
 
-long long Processes::totalPhysicalMemory() {
+long long Processes::totalPhysicalMemory()
+{
     return d->mAbstractProcesses->totalPhysicalMemory();
 }
 
-long Processes::numberProcessorCores() {
+long Processes::numberProcessorCores()
+{
     return d->mAbstractProcesses->numberProcessorCores();
 }
 
-void Processes::answerReceived( int id, const QList<QByteArray>& answer ) {
+void Processes::answerReceived(int id, const QList<QByteArray> &answer)
+{
     KSysGuard::ProcessesRemote *processes = qobject_cast<KSysGuard::ProcessesRemote *>(d->mAbstractProcesses);
-    if(processes)
+    if (processes)
         processes->answerReceived(id, answer);
 }
 
-QList< QPair<QDateTime,uint> > Processes::historiesAvailable() const
+QList<QPair<QDateTime, uint>> Processes::historiesAvailable() const
 {
-    if(!d->mIsLocalHost)
-        return QList< QPair<QDateTime,uint> >();
-    if(!d->mHistoricProcesses)
+    if (!d->mIsLocalHost)
+        return QList<QPair<QDateTime, uint>>();
+    if (!d->mHistoricProcesses)
         d->mHistoricProcesses = new ProcessesATop();
 
     return d->mHistoricProcesses->historiesAvailable();
@@ -510,25 +506,25 @@ QList< QPair<QDateTime,uint> > Processes::historiesAvailable() const
 
 void Processes::useCurrentData()
 {
-    if(d->mUsingHistoricalData) {
+    if (d->mUsingHistoricalData) {
         delete d->mHistoricProcesses;
         d->mHistoricProcesses = nullptr;
-        connect( d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
+        connect(d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
         d->mUsingHistoricalData = false;
     }
 }
 
 bool Processes::setViewingTime(const QDateTime &when)
 {
-    if(!d->mIsLocalHost) {
+    if (!d->mIsLocalHost) {
         d->mLastError = NotSupported;
         return false;
     }
-    if(!d->mUsingHistoricalData) {
-        if(!d->mHistoricProcesses)
+    if (!d->mUsingHistoricalData) {
+        if (!d->mHistoricProcesses)
             d->mHistoricProcesses = new ProcessesATop();
-        disconnect( d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
-        connect( d->mHistoricProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
+        disconnect(d->mAbstractProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
+        connect(d->mHistoricProcesses, &AbstractProcesses::processesUpdated, this, &Processes::processesUpdated);
         d->mUsingHistoricalData = true;
     }
     return d->mHistoricProcesses->setViewingTime(when);
@@ -536,11 +532,11 @@ bool Processes::setViewingTime(const QDateTime &when)
 
 bool Processes::loadHistoryFile(const QString &filename)
 {
-    if(!d->mIsLocalHost) {
+    if (!d->mIsLocalHost) {
         d->mLastError = NotSupported;
         return false;
     }
-    if(!d->mHistoricProcesses)
+    if (!d->mHistoricProcesses)
         d->mHistoricProcesses = new ProcessesATop(false);
 
     return d->mHistoricProcesses->loadHistoryFile(filename);
@@ -548,27 +544,25 @@ bool Processes::loadHistoryFile(const QString &filename)
 
 QString Processes::historyFileName() const
 {
-    if(!d->mIsLocalHost || !d->mHistoricProcesses)
+    if (!d->mIsLocalHost || !d->mHistoricProcesses)
         return QString();
     return d->mHistoricProcesses->historyFileName();
 }
 QDateTime Processes::viewingTime() const
 {
-    if(!d->mIsLocalHost || !d->mHistoricProcesses)
+    if (!d->mIsLocalHost || !d->mHistoricProcesses)
         return QDateTime();
     return d->mHistoricProcesses->viewingTime();
 }
 
 bool Processes::isHistoryAvailable() const
 {
-    if(!d->mIsLocalHost)
+    if (!d->mIsLocalHost)
         return false;
-    if(!d->mHistoricProcesses)
+    if (!d->mHistoricProcesses)
         d->mHistoricProcesses = new ProcessesATop();
 
     return d->mHistoricProcesses->isHistoryAvailable();
 }
 
 }
-
-
